@@ -17,7 +17,7 @@ s.bind('tcp://127.0.0.1:5555')
 stream = uzmq.ZMQ(loop, s)
 
 def echo(handle, msg, err):
-    print " ".join(msg)
+    print(msg[0])
     stream.write_multipart(msg)
 
 stream.start_read(echo)
